# CoreX ai_vision - sam

This package provides an implementation of the CoreX ai_vision interface for sam.

## Installation
~~~bash
pip install corex-ai_vision-sam
~~~

## Usage
~~~python
from corex_ai_vision_sam.handler import SamHandler
handler = SamHandler()
handler.example_method()
~~~

## License
This package is licensed under the MIT License. See [LICENSE](../LICENSE) for details.
